Gets information on friendship between authenticated user and up to 100 other users.
my_friendships(user, parse = FALSE, token = NULL)Character vector of screen names or user ids.
See as_screenname() for more details.
If TRUE, the default, returns a tidy data frame. Use FALSE
to return the "raw" list corresponding to the JSON returned from the
Twitter API.
Expert use only. Use this to override authentication for
a single API call. In most cases you are better off changing the
default for all calls. See auth_as() for details.
Other friends:
lookup_friendships()